jaclearn.imageaug.executor
==========================

.. automodule:: jaclearn.imageaug.executor

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      AugmentorExecutorBase
      ImageAugmentorExecutor
      ImageCoordAugmentorExecutor
   
   

   
   
   

   
   
   








.. rubric:: Class AugmentorExecutorBase
.. autoclass:: AugmentorExecutorBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ImageAugmentorExecutor
.. autoclass:: ImageAugmentorExecutor
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ImageCoordAugmentorExecutor
.. autoclass:: ImageCoordAugmentorExecutor
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







